# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/dev-lang/R/R-2.0.1.ebuild,v 1.8 2005/07/01 11:53:30 kugelfang Exp $

inherit fortran toolchain-funcs

IUSE="blas X tcltk gnome zlib bzip2 pcre"
DESCRIPTION="R is GNU S - A language and environment for statistical computing and graphics."
SRC_URI="http://cran.r-project.org/src/base/R-2/${P}.tar.gz"
#There are daily release patches, don't know how to utilize these
#"ftp://ftp.stat.math.ethz.ch/Software/${PN}/${PN}-release.diff.gz"
HOMEPAGE="http://www.r-project.org/"
DEPEND="virtual/libc
		>=dev-lang/perl-5.6.1-r3
		>=sys-libs/readline-4.1-r3
		zlib? ( >=sys-libs/zlib-1.1.3-r2 )
		>=media-libs/jpeg-6b-r2
		>=media-libs/libpng-1.2.1
		blas? ( virtual/blas )
		X? ( virtual/x11 )
		tcltk? ( dev-lang/tk )
		pcre? ( dev-libs/libpcre )
		bzip2? ( app-arch/bzip2 )
		gnome? ( >=gnome-base/gnome-libs-1.4.1.4
			>=gnome-base/libglade-0.17
			>=dev-libs/libxml-1.8.16
			=gnome-base/orbit-0*
			>=media-libs/imlib-1.9.10
			>=x11-libs/gtk+-1.2.10
			>=dev-libs/glib-1.2.10
			>=media-sound/esound-0.2.23
			>=media-libs/audiofile-0.2.1 )"
SLOT="0"
LICENSE="GPL-2 LGPL-2.1"
KEYWORDS="amd64 ppc ppc64 sparc x86"

pkg_setup() {
	# Test for a 64 bit architecture - f2c won't work on 64 bit archs with R.
	# Thanks to vapier for providing the test.
	echo 'int main(){}' > test.c
	$(tc-getCC) -c test.c -o test.o
	if file test.o | grep -qs 64-bit ; then
		einfo "64 bit architecture detected, using g77."
		FORTRAN="g77"
	else
		FORTRAN="g77 f2c"
	fi
	fortran_pkg_setup
}

src_compile() {
	local myconf="--enable-static --enable-R-profiling --enable-R-shlib --with-readline"

	use zlib || myconf="${myconf} --with-zlib"		#default disabled
	use bzip2 || myconf="${myconf} --with-bzlib"	#default disabled
	use pcre || myconf="${myconf} --with-pcre"   	#default disabled

	# Using the blas USE flag now instead atlas, as atlas now
	# has been broken into blas-atlas and lapack-atlas.
	use blas || myconf="${myconf} --without-blas" #default enabled
	# --with-lapack is deprecated now by upstream
	# use lapack && myconf="${myconf} --with-lapack" #default disabled

	use X || myconf="${myconf} --without-x" #default enabled

	if use tcltk; then
		#configure needs to find the files tclConfig.sh and tkConfig.sh
		myconf="${myconf} --with-tcltk --with-tcl-config=/usr/lib/tclConfig.sh --with-tk-config=/usr/lib/tkConfig.sh"
	else
		myconf="${myconf} --without-tcltk"
	fi

	use gnome && myconf="${myconf} --with-gnome" #default disabled

	econf \
		--host=${CHOST} \
		--prefix=/usr \
		--infodir=/usr/share/info \
		--mandir=/usr/share/man \
		${myconf} || die "./configure failed"

	emake || die
}

src_install() {
	make \
		prefix=${D}/usr \
		mandir=${D}/usr/share/man \
		infodir=${D}/usr/share/info \
		rhome=${D}/usr/$(get_libdir)/R \
		install || die "Installation Failed"

	#fix the R wrapper script to have the correct R_HOME_DIR
	#sed regexp borrowed from included debian rules
	sed \
		-e '/^R_HOME_DIR=.*/s::R_HOME_DIR=/usr/lib/R:' \
		-i ${D}/usr/$(get_libdir)/R/bin/R \
		|| die "sed failed"

	#R installs two identical wrappers under /usr/bin and /usr/lib/R/bin/
	#the 2nd one is corrected by above sed, for the 1st
	#I'll just symlink it into /usr/bin
	cd ${D}/usr/bin/
	rm R
	dosym ../$(get_libdir)/R/bin/R /usr/bin/R
	cd ${S}

	dodir /etc/env.d
	echo > ${D}/etc/env.d/99R "LDPATH=/usr/$(get_libdir)/R/lib"


	dodoc AUTHORS BUGS COPYING* ChangeLog FAQ INSTALL *NEWS README \
		RESOURCES THANKS VERSION Y2K

	#Add rudimentary menu entry if gnome
	if use gnome; then
		insinto /usr/share/gnome/apps/Applications
		doins ${FILESDIR}/R.desktop
		insinto /usr/share/pixmaps
		doins ${FILESDIR}/R-logo.png
	fi

}
